#Change log versions
## 1.2a
## 1.1
- minor changes to display standards and physicsConstants
- added gears and struct_meca
## 1.0.13
- added pytest_util
- dsp.stddisp bug fix inset
- displayStandards tick_direction tdir
- added axPos full 'F' key
